Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(395)

Unified Diff: sky/examples/widgets/spinning_mixed.dart

Issue 1190793002: Rename UINode to Widget. (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sky/examples/widgets/sector.dart ('k') | sky/sdk/lib/editing2/editable_text.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sky/examples/widgets/spinning_mixed.dart
diff --git a/sky/examples/widgets/spinning_mixed.dart b/sky/examples/widgets/spinning_mixed.dart
index 4efa0dcb4c59d4f585e95da4ebcf6a1e06988fc0..1de1fcdf2454ef98e367fd71e01d6613c23df24b 100644
--- a/sky/examples/widgets/spinning_mixed.dart
+++ b/sky/examples/widgets/spinning_mixed.dart
@@ -9,7 +9,7 @@ import 'package:sky/rendering/box.dart';
import 'package:sky/rendering/flex.dart';
import 'package:sky/widgets/basic.dart';
import 'package:sky/widgets/raised_button.dart';
-import 'package:sky/widgets/ui_node.dart';
+import 'package:sky/widgets/widget.dart';
import 'package:vector_math/vector_math.dart';
import '../lib/solid_color_box.dart';
@@ -26,7 +26,7 @@ void addFlexChildSolidColor(RenderFlex parent, sky.Color backgroundColor, { int
class Rectangle extends Component {
Rectangle(this.color, { String key }) : super(key: key);
final Color color;
- UINode build() {
+ Widget build() {
return new Flexible(
child: new Container(
decoration: new BoxDecoration(backgroundColor: color)
@@ -35,7 +35,7 @@ class Rectangle extends Component {
}
}
-UINode builder() {
+Widget builder() {
return new Flex([
new Rectangle(const Color(0xFF00FFFF), key: 'a'),
new Container(
@@ -74,18 +74,18 @@ void rotate(double timeStamp) {
}
void main() {
- // Because we're going to use UINodes, we want to initialise its
+ // Because we're going to use Widgets, we want to initialise its
// AppView, not use the default one. We don't really need to do
// this, because RenderBoxToUINodeAdapter does it for us, but
// it's good practice in case we happen to not have a
// RenderBoxToUINodeAdapter in our tree at startup, or in case we
// want a renderViewOverride.
- UINodeAppView.initUINodeAppView();
+ WidgetAppView.initWidgetAppView();
RenderFlex flexRoot = new RenderFlex(direction: FlexDirection.vertical);
RenderProxyBox proxy = new RenderProxyBox();
- new RenderBoxToUINodeAdapter(proxy, builder); // adds itself to proxy
+ new RenderBoxToWidgetAdapter(proxy, builder); // adds itself to proxy
addFlexChildSolidColor(flexRoot, const sky.Color(0xFFFF00FF), flex: 1);
flexRoot.add(proxy);
@@ -94,6 +94,6 @@ void main() {
transformBox = new RenderTransform(child: flexRoot, transform: new Matrix4.identity());
RenderPadding root = new RenderPadding(padding: new EdgeDims.all(20.0), child: transformBox);
- UINodeAppView.appView.root = root;
+ WidgetAppView.appView.root = root;
addPersistentFrameCallback(rotate);
}
« no previous file with comments | « sky/examples/widgets/sector.dart ('k') | sky/sdk/lib/editing2/editable_text.dart » ('j') | no next file with comments »
@@ -74,18 +74,18 @@ void rotate(double timeStamp) {
// AppView, not use the default one. We don't really need to do
- // this, because RenderBoxToUINodeAdapter does it for us, but
+ // this, because RenderBoxToWidgetAdapter does it for us, but
// it's good practice in case we happen to not have a
@@ -74,18 +74,18 @@ void rotate(double timeStamp) {
// it's good practice in case we happen to not have a
- // RenderBoxToUINodeAdapter in our tree at startup, or in case we
+ // RenderBoxToWidgetAdapter in our tree at startup, or in case we
// want a renderViewOverride.

Powered by Google App Engine
This is Rietveld 408576698